function EOR_cost = Cost_CO2_EOR_8(year, HCPV_x,pp,pOil_2016,n,k, inf, ro, eff_Oilprod, eff_CO2inj, depth, FVF)
%% Operating costs (OPEX) for ONE EOR pattern except for CO2 monitor costs which applies to whole field
%eff_Oilprod = (oil production rate /OOIP) - multiply by OOIP & m3_bbl conversion to get STB
%OOIP = HCPV_x/FVF (FVF = oil formation volume factor) 
%ro = density of CO2 in reservoir conditions 614.08 kg/m3
%---- OPEX EOR ----
inf_2004_2016 = 1.27; % CPI inflation calculator 
inf_2010_2016 = 1.10; % same 
inf_2014_2016 = 1.017; % CPI inflation calculator

m3_bbl = 6.2898; % m3 conversion to bbl 
m3_scf = 35.31466247; %m3 conversion to scf
m_ft = 3.28084; % conversion from 1m to 3.28084ft
Mm3_m3 = 10^6; %Million m3 to m3 
ro_CO2_surf = 1.977; % CO2 desnity @ standard conditions kg/m3
Liq_multiplier = 1.5; % Assume that for every bbl of oil produced 0.5 bbls of water is produced

GA_factor = 0.2; % General & Administrative cost factor in 2014 US$ based on Fukai et al. 
CO2_OM_recyc_factor = 0.01; % multiply by price of oil * Mscf(1000s) of CO2 processed per year (produced & injected)
Liq_lift_factor = 0.25; %[$/STB] multiply by the amount of oil + 1/2 oil (water) processing in STB
Period_OM_1 = 26878; % Periodic O&M cost factor 1 
Period_OM_2 = 1.1*10^-4; %Periodic O&M exp cost factor 2 (in exponential) times depth (ft)

%1) Liquid lifting costs per pattern based on ARI 2006 reported in McCoy&Rubin
%in 2004US$ 
Liq_lift_cost = inf_2004_2016*m3_bbl*Liq_multiplier*Mm3_m3*Liq_lift_factor*(eff_Oilprod*HCPV_x(k)*(1/FVF)); 

%2) Periodic O&M Costs per pattern based on W-TX region from Lewin & Associates regression
%models reported in McCoy & Rubin 2009 in 2004 US$
O_M_periodic = zeros(1,n+1)+inf_2004_2016*Period_OM_1*exp(Period_OM_2*depth(k)*m_ft); 

% 3) CO2 recycling O&M costs per pattern from ARI2006 reference reported in 2004 US$ in
% McCoy & Rubin PhD Thesis 
CO2_recyc_OM = CO2_OM_recyc_factor*pOil_2016*(eff_CO2inj*HCPV_x(k))*ro*(1/ro_CO2_surf)*m3_scf*(10^3); %10^3 multiplication for Mm3 (millions) to Mscf (thousands)
%CO2_recyc_OM=0.01*inf_2014_16.*pOil_2016*eff_CO2prod*HCPV_x(k)*pp(k)*ro*(1/ro_CO2_surf)*m3_scf;

%4)General & Administrative Costs per pattern from ARI 2006 reported by Fukai et al. 2016
%in 2014US$ costs
G_A=GA_factor*inf_2014_2016*(O_M_periodic+Liq_lift_cost);

%5)**FOR WHOLE FIELD NOT PER PATTERN** 
%Fixed cost: IEA Insights 2014 esimate on fixed monitoring cost for CO2 used for EOR
%for whole field reported in 2010 US$
CO2_monitor=zeros(1,n+1)+inf_2010_2016*2*10^6;
%CO2_monitor=zeros(1,n+1)+5*10^6; % according to Petra Nova's yearly
%operating cost

EOR_cost=(((Liq_lift_cost + O_M_periodic + CO2_recyc_OM + G_A)*pp(k)) + CO2_monitor).*((1+inf).^((year):(year+n))); % $/y
end 