%% MIICE model - Clea Kolster, Mohammad Masnadi, Sam Krevor, Niall Mac Dowell, Adam R. Brandt. 
%% Initializing parameters
clearvars
close all
clc
% run Project_variables.m 
%% Load variables, constants and parameters
load constants1.mat
load variables1.mat
%% Start model iteration runs
%----Number of field realisations
%-------- Select from i number of random fields
num_fields = 1000; % number of field iterations
%i = 10000; 
                    
                    %% Random Field Generations
                    %---------field characteristics range
                    rng(1); % seed for randomization
                    poro = (randi([5,30], 1, i)) / 100; % porosity of field [fraction]
                    Swi  = (randi([15 75], 1, i)) / 100; % initial water saturation i.e. (1 - Soi) [fraction]
                    h    = randi([10 50], 1, i); % net pay thickness [m]
                    A    = randi([8094000 80920000], 1, i); % [m2]
                    depth = randi([914, 3140], 1, i);  % [metres] %3140
                    perm = (randi([1, 110], 1, i))/(10^(15)); % [m2]
                    HCPV = poro.*Swi.*h.*A_pattern*1e-6; %Million m3
                    p = A / A_pattern ; % maximum number of patterns rule of thumb - 1 pattern is 161880 m2
                    HCPV_pp = HCPV.*p; % Hyrocarbon pore volume x pattern number
                    HCPV_pp_x = HCPV_pp( HCPV_pp > 50 ); % eliminate non sensical values for field
                    HCPV_x = HCPV ;%(HCPV_pp >50);
                    p_x = p ;%(HCPV_pp > 50);

                    %% Vector sizing
                    %------ Production, Storage and Deployment Numbers-----
                    %---------- Build or no build-------------
                    build_1 = zeros (1, d);
                    cumulative_build = zeros (1, d);
                    Capacity_build = zeros(1, d); 
                    NPV_sum = zeros (d, num_fields);
                    Project_size = zeros (d, num_fields); % What size CCS projects for field k in year year
                    %----- Oil to CO2 revenue ratio
                    Oil_to_CO2_rev = zeros (1, d); % fraction of oil revenue to CO2 revenue
                    Oil_rev_year = zeros (d, num_fields); 
                    CO2_rev_year = zeros (d, num_fields); 
                    Oil_rev_avg = zeros(1, d); 
                    CO2_rev_avg = zeros(1, d); 
                    build_decimal = zeros(1, d);
                    Cumulative_capacity_build = zeros(1, d);
                    Cumulative_stored = zeros(1, d);
                    Cumulative_oil = zeros(1, d);
                    Stored_CO2_year = zeros(1,d);
                    Produced_Oil_year = zeros (1,d);
                    Stored_CO2 = zeros(1, num_fields);
                    Emitted_CO2 = zeros(1, num_fields);
                    Injected_CO2_year = zeros(1, d);
                    Produced_CO2_year = zeros(1,d);
                    Cumulative_not_captured = zeros(1, d);
                    Cumulative_stored_yrly = zeros(1, d);
                    Cumulative_oil_yrly = zeros(1, d);
                    Stored_CO2_yrl_avg = zeros (1, d);
                    Stored_CO2_yrl_avg_year = zeros(1, d);
                    Produced_Oil_yrly_avg = zeros(1, d);
                    Produced_Oil_yrly_avg_year = zeros(1, d);
                    Cumulative_produced = zeros(1, d);
                    Leaked_CO2_year = zeros(1, d);
                    Cumulative_leaked = zeros(1, d);
                    Not_captured = zeros(1, d);
                    Emitted_CO2_year = zeros(1, d);
                    Cumulative_emitted = zeros(1, d);
                    NPV_year = zeros(1, d); 
                    %---- Field level ------
                    Produced_Oil = zeros(1, num_fields);
                    Produced_CO2 = zeros(1, num_fields);
                    Injected_CO2 = zeros(1, num_fields);
                    Leaked_CO2 = zeros(1, num_fields);
                    Q_max_inj_comp = zeros (1 ,num_fields);
                    pp = zeros (1, num_fields);
                    j_year = zeros (num_fields, n+1);
                    pp_tot = zeros (1, num_fields);
                    max_CO2_injection = zeros(1, num_fields);
                    
                    %--- Cost vector sizing------
                    Capture_capex = zeros (1,d);
                    EOR_capex = zeros (1, d);
                    Overall_capex = zeros (1, d);
                    CRF = zeros (1, d);
                    Cost_of_CO2 = zeros (1,d);
                    Cost_of_CO2_adjusted = zeros(1, d);
                    OPEX_capture = zeros(1,d);
                    capex_EOR_ini = zeros(1, num_fields);
                    
                    %--- Average characteristics vector sizing
                    Poro_avg = zeros (1,d);
                    Soil_avg = zeros (1,d);
                    h_avg = zeros (1,d);
                    depth_avg = zeros (1,d);
                    perm_avg = zeros (1,d);
                    Area_avg = zeros (1,d);
                    
                    %% Learning, Installed Capacity & Change in Oil Price
                    %-------- Learning Rate Calculation
                    learn = log(1-LR)/log(2);   % learning rate variable b of Wright learning curve
                    
                    %------ Initial amount of CCS deployed ----
                    build = Q_i ; % Current Global Installed Capacity
                    build_new = 0; % Year 1 no prior build within model start at 0
                    
                    %                     %------ Oil price changes over the years------
                    %                     pOil = pOil_2016*(g.^(0:(d-1))); %Price of oil over timeline considered is a vector of length d
                    %
                    %--Nothing has been produced - initialise year count
                    year_initial = 0;
                    %%   Assess year on year how many projects are worth investing in
                    for year = 1:1:d
                        
                        %------ Oil price changes over the years------
                        pOil = pOil_2016*(g^(year-1)) ; %Price of oil over timeline considered is a vector of length d
                        
                        %Incremental increase in carbon tax 1$ per year
                        if climate_conscious == 0
                            pCO2 = pCO2_start_low + 1*(year-1);
                            pCO2_initial = pCO2_start_low;
                        else
                            pCO2 = pCO2_start_high + 2*(year-1);
                            pCO2_initial = pCO2_start_high;
                        end
                        
                        %-Choice of production profile chooses every year
                        i_CO2_x = randi([1,3],1,i); % Choose from the 3 production profiles low, medium, high
                        %
                        %                         %------- CO2 capture rate -------
                        %                         % Choose CO2 capture rate to start with and for how
                        %                         % long start up time is
                        %                         cap_rate = 0.1;                   %Assuming 90% capture
                        %                         Maximum_CCS_size = 4; %Mt captured from large coal firing power plant
                        %
                        %---------- initialise k ------
                        k = 1;
                        
                        %%  Assessing the Economic Viability of Each Field at a Given Year
                        while (k <= num_fields)
                            
                            %----- Sizing cash flow vectors----
                            cap_cost = zeros(1, n + 1);
                            
                            %----Sizing yearly Oil & CO2 production, injection,
                            %emission for each field for each size
                            yr_Oil_prod1 = zeros(Maximum_CCS_size, n+1);
                            yr_CO2_injected1 = zeros(Maximum_CCS_size,n+1);
                            yr_CO2_produced1 = zeros(Maximum_CCS_size,n+1);
                            yr_CO2_stored1 = zeros(Maximum_CCS_size,n+1);
                            yr_CO2_leak1 = zeros(Maximum_CCS_size,n+1);
                            yr_CO2_inj_pp1 = zeros(Maximum_CCS_size,n+1);
                            %----- Sizing revenue streams saved
                            CO2_revonly_proj = zeros(1, Maximum_CCS_size); 
                            Oil_rev_proj = zeros(1, Maximum_CCS_size);
                            %---Sizing CCS size choice
                            CO2_cap = zeros(Maximum_CCS_size, 1);
                            NPV_sizes = zeros(num_fields, Maximum_CCS_size);
                            
                            %%---Test all CCS size options 1Mt, 2Mt, 3Mt, 4Mt, 5Mt yearly rates
                            for start_i = 1:1:Maximum_CCS_size
                                
                                CO2_cap(start_i) = 1*start_i ; % 1Mt multiplied by a factor
                                oil_factor = 0.001;
                                
                                if CO2_cap(start_i) == 1 
                                    D = diameters(1); % 8 inch diameter (diameters(1)) for 1 -2 MTCO2/year
                                elseif CO2_cap(start_i) >= 1.13 && CO2_cap(start_i) <= 3.25
                                    D = diameters(2);
                                else
                                    D = diameters(3); % 12 inch diameter (diameters(2)) for more than 3MTCO2/year
                                end
                                CO2_cap_vol = ((CO2_cap(start_i).*10^6)./ro).*10^-3 ; %Mm3/year
                                
                                %---- Capital Cost of transport pipeline determined by diameter
                                % needed for capture capacity
                                capex_trans_ini = Initial_Capital_Transport (D, L);
                                
                                %-------- Sizing Cumulative CO$_2$ injection, production and Oil production vectors-------
                                cum_CO2prod = zeros(1,n+1);
                                cum_CO2inj = zeros(1,n+1);
                                cum_Oilprod = zeros(1,n+1);
                                
                                %-------- parameters of Oil & CO$_2$ Production fit curves -----
                                i_CO2 = i_CO2_x;
                                i_Oil = i_CO2_x;
                                
                                %-------- High, medium, low production parameters
                                CO2prod_P = [0.47915, 1.276, 0.9086, 1.078; ... %P90 Res. Simulation
                                    0.4, 0.6357, 0.9292, 0.5785; ... %ODC
                                    0.33, 0.3155, 0.8515, 0.1492]; % CV
                                
                                %------- High, medium, low production parameters
                                Oilprod_P= [0.08989,  0.3818,  3.449,  0.3415;... %P90 Res. Sim.
                                    0.01, 0.1774, 4.86, 0.447;... %ODC
                                    0.0, 0.105, 9.813, 0.4213] ; %CV
                                
                                %---- Calculate maximum injection rate ----
                                Delta_P = (frac_g - hydro_g)*depth(k)*con; % [Pa] Darcy pressure differential
                                Q_max_inj = (2*pi*h(k)*perm(k)*(frac_g - hydro_g)*depth(k)*con)/(mu*log(r_e/r_w)); %[m3/s]
                                Q_max_inj_comp(k) = Q_max_inj*3600*24*365*(10^-6); %[Mm3/year]
                                
                                %---- Capital Cost calculation for CO2-EOR
                                capex_EOR_ini(k) = EOR_initial_capital_cost_1(depth, Q_max_inj,k);
                                
                                %------------CO2-EOR Production Curves--------------------
                                j_end = zeros(num_fields, n+2);
                                pp_total = zeros(num_fields, n+1); % counts number of patterns that are opening
                                l=1; %Counts the number of times you close pattern set to open new ones
                                l_final = 1 ; % Documents number of times new set of patterns are opened
                                j_end(k,l) = 0 ; %indicates at what year patterns are added delayed by 1 year (i.e. year 0 starts with 0 patterns)
                                %j_stop = 0; % this variable only changes number if there is no more room in the field to accomodate more patterns opening
                                j=1 ; %year of field life 1 to 30
                                
                                while (j <= n+1)
                                    %for j = 1 : (n+1) 
                                    pp (k) = ceil(CO2_cap_vol/(oil_factor*Q_max_inj_comp(k)));
                                    pp_total(k, j) = pp(k)*l;
                                    pp_tot(k) = pp(k)*l;
                                    
                                    %---- Condition on area of the field A
                                    if pp_total(k,j) > p_x(k)
                                        oil_factor = oil_factor + add;
                                        j = 1;
                                        j_end(k,l) = 0 ;
                                        l=1; %Counts the number of times you close pattern set to open new ones
                                        l_final = 1 ; % Documents number of times new set of patterns are opened
                                        continue
                                    end
                                    
                                    if (j == 1)
                                        cum_CO2inj(1,j)=(CO2_cap_vol*(j))./(HCPV_x(k).*pp(k)); %[1/HCPV]
                                        cum_CO2prod(1,j) = 0;                                        %[1/HCPV]
                                        cum_Oilprod(1,j) = 0;                                        %[1/OOIP]
                                        
                                    else
                                        cum_CO2inj(1,j)  = ((CO2_cap_vol*(j-j_end(k,l)))/(HCPV_x(k).*pp(k)))+ cum_CO2prod(j-j_end(k,l)-1); % [1/HCPV]
                                        cum_CO2prod(1,j) = CO2_production_pat(i_CO2(k), cum_CO2inj(j-j_end(k,l)-1), CO2prod_P); %[1/HCPV]
                                        cum_Oilprod(1,j) = Oil_production(i_Oil(k), cum_CO2inj(j-j_end(k,l)-1), Oilprod_P);%[1/OOIP]
                                        
                                    end
                                    
                                  %Condition on closing a pattern and
                                  %documentings time stamp
                                    if j > 1 && (cum_Oilprod(1,j)/cum_CO2inj(1,j) <= 0.11) 
                                        cum_CO2inj(1,j)=(CO2_cap_vol*(1))./(HCPV_x(k).*pp(k));
                                        cum_CO2prod(1,j) = 0;
                                        cum_Oilprod(1,j) = 0;
                                        l = l+1;
                                        j_end(k,l) = j-1;
                                        l_final = l;
                                        
                                    end
                                    j = j + 1; % next year of field life
                                end
                                
                                eff_pp_life = ceil((n+1)/l_final); % Number of years that production takes place on same number of patterns
                                eff_CO2inja = repmat(diff([0 cum_CO2inj(1,1:eff_pp_life)],1,2),1, l_final); %[1/HCPV]
                                eff_CO2inj = vertcat(eff_CO2inja(1:(n+1)));
                                eff_CO2proda = repmat(diff([0 cum_CO2prod(1,1:eff_pp_life)],1,2),1, l_final); %[1/HCPV]
                                eff_CO2prod = vertcat(eff_CO2proda(1:(n+1)));
                                eff_CO2store = eff_CO2inj - eff_CO2prod ;                 %[1/HCPV]
                                eff_Oilproda = repmat(diff([0 cum_Oilprod(1,1:eff_pp_life)],1,2),1, l_final); %[1/OOIP]
                                eff_Oilprod = vertcat(eff_Oilproda(1:(n+1)));
                                
                                %--------------Yearly CO2 Fate and Yearly Oil Prod----
                                %----CO2 fate: stored, injected, produced,
                                %leaked (MtCO_2/year)
                                yr_CO2_inj_pp = CO2_inj_pat_1 (eff_CO2inj, HCPV_x, ro, k); % CO2 injected per pattern
                                yr_CO2_stored  = CO2_storage_5(ro, eff_CO2store, HCPV_x, pp, k); % yearly CO2 stored over whole field
                                yr_CO2_produced = CO2_produced_1leak(ro,eff_CO2prod,HCPV_x, pp, k, leak); %yearly rate of CO2 production to recycle over whole field
                                yr_CO2_leak = CO2_leaked1(ro,eff_CO2prod,HCPV_x, pp, k, leak); %yearly rate of CO2 leakage assumed to be 0.5% of CO2 produced
                                yr_CO2_injected = CO2_injected_1(ro,eff_CO2inj, HCPV_x, pp, k) ; % CO2 injected throughout whole field all patterns at a time
                                
                                yr_Oil_prod = Oil_sale_4(eff_Oilprod, HCPV_x, pp, FVF, k); %bbl/year
                                
                                %---Register yearly rates for every CCS
                                %size project group
                                yr_CO2_stored1(start_i, 1:n+1) = yr_CO2_stored;
                                yr_CO2_produced1(start_i, 1:n+1) = yr_CO2_produced;
                                yr_CO2_leak1(start_i, 1:n+1) = yr_CO2_leak;
                                yr_CO2_injected1(start_i, 1:n+1) = yr_CO2_injected;
                                yr_CO2_inj_pp1(start_i, 1:n+1) = yr_CO2_inj_pp;
                                yr_Oil_prod1(start_i, 1:n+1) = yr_Oil_prod;
                                
                                %---Limit CO$_2$ injection per pattern to avoid
                                %fracture
                                max_CO2_injection(k) = max(yr_CO2_inj_pp);
                                if (Q_max_inj_comp(k) < max_CO2_injection(k));
                                    %k=k+1;
                                    break
                                end
                                %plot(cum_CO2inj, cum_CO2prod, 'g', cum_CO2inj, cum_Oilprod)
                                
                                
                                %---- ALL CAPEX -------
                                if (sum(build_1) <= learn_lim)
                                    
                                    CAPEX_cap = (capex_cap_ini)*(((sum(build_1)+Q_i)/Q_i)^learn);  % Capture overnight capital cost per Mt CO2
                                    %CAPEX_trans = (capex_trans_ini); %no learning
                                    CAPEX_EOR = capex_EOR_ini(k); %no learning
                                    CAPEX_trans = (capex_trans_ini)*(((sum(build_1)+Q_i)/Q_i)^learn); % Transport overnight capital cost of pipeline
                                    %CAPEX_EOR = capex_EOR_ini(k)*(((sum(build_1)+Q_i)/Q_i)^learn);    % CO2_EOR cost for 1 patern times number of patterns pp
                                else
                                    CAPEX_cap = (capex_cap_ini*CO2_cap(start_i))*((learn_lim+Q_i)^(learn));  %Capture overnight capital cost
                                    %CAPEX_trans = (capex_trans_ini); %no learning
                                    CAPEX_EOR = capex_EOR_ini(k); %no learning
                                    CAPEX_trans = (capex_trans_ini)*((learn_lim+Q_i)^(learn)); % Transport overnight capital cost of pipeline
                                    %CAPEX_EOR = capex_EOR_ini(k)*((learn_lim+Q_i)^(learn));    % CO2_EOR cost for 1 patern times number of patterns pp
                                end
                                
                                TOTAL_CAPEX = -(CAPEX_cap*CO2_cap(start_i) + CAPEX_trans + CAPEX_EOR*pp_tot(k))*Equity.*((1+inf)^year); % Overnight capital cost considered
                                
                                %-------Positive cash flow ---------
                                CO2_rev = revenue_CO2_1_many(yr_CO2_stored, CO2_cap, pCO2, cap_rate, inf, n, year, start_i); %includes negative revenue from CO2 not stored & 10% not captured
                                %CO2_rev = revenue_CO2_1_SA(yr_CO2_stored, CO2_cap, pCO2, cap_rate, inf, n, year, start_i); %CO2 that is not stored and vented is stored in saline aquifer
                                Oil_rev = revenue_Oil_1(yr_Oil_prod, pOil, year, n, inf);
                                
                                %----Save revenue streams for each project
                                %size
                                CO2_revonly_proj(start_i) = sum(yr_CO2_stored*pCO2)*10^6; 
                                Oil_rev_proj(start_i) = sum(Oil_rev); 
                                
                                %-------Operational Negative cash flow -------
                                cap_cost   = Cost_capture_2_many(COE, CO2_cap, inf, n, year, start_i);
                                trans_cost = Cost_transport_2_many(CO2_cap, inf, n, year,  start_i);
                                EOR_cost = Cost_CO2_EOR_8(year, HCPV_x,pp,pOil_2016,n,k, inf, ro, eff_Oilprod, eff_CO2inj, depth, FVF);
                                
                                %------ Amortized loan cost ------
                                annualization = (IR*(1+IR)^(n+1))/(((1+IR)^(n+1))-1);
                                Debt_payment = (-TOTAL_CAPEX * (1 - Equity) * annualization)*((1+inf).^(((year):(year+n))));

                                %------Earnings before tax -------
                                tax_cost = Tax(Oil_rev, CO2_rev, Roy, Sev, Adv, Corp_tax);
                                
                                %-----Net free cash flow ---------
                                %Cash_flow=zeros(1,n+2);
                                %Cash_flow = [repmat(TOTAL_CAPEX, num_fields, 1) CO2_rev+Oil_rev-cap_cost-trans_cost-EOR_cost-tax_cost];
                                %Cash_flow = [TOTAL_CAPEX CO2_rev+Oil_rev-cap_cost-trans_cost-EOR_cost-tax_cost];
                                
                                %-----Discounted Cash Flow -------
                                Discounted = (CO2_rev + Oil_rev - cap_cost*CO2_cap(start_i) - trans_cost - EOR_cost - tax_cost - Debt_payment)./((1+NR).^(1:n+1));
                                Cash_flow_discounted = [TOTAL_CAPEX Discounted]; %Overnight capital cost year 0 and discounted cash flow
                                %plot(1:n+1, Cash_flow_discounted(1:n+1));
                                %Discounted_cash_flow_field1(k) = Cash_flow_discounted(k);
                                %--- Calculate NPV for each project size option
                                NPV_sizes(k, start_i) = sum(Cash_flow_discounted);
                                
                            end
                            
                            %--Decide which project size gives higher NPV
                            %for field k at year year
                            [NPV_sorted, proj_size] = sort(NPV_sizes(k,:), 'descend');
                            Project_size(year, k) = proj_size(1); % CCS project size with highest NPV
                            
                            %----Calculate NPV/revenue streams --------------
                            NPV_sum (year,k) = NPV_sizes(k, Project_size(year, k)); % store NPV for each field with best project option
                            Oil_rev_year(year, k) = Oil_rev_proj(Project_size(year, k)); % proportion of revenue from from oil 
                            CO2_rev_year(year, k) = CO2_revonly_proj(Project_size(year, k)); %proportion of revenue from CO2 (minus tax paid on CO2 not stored)
                            
                            %-----Calculate flow rate outputs for field k
                            %of CO2 & Oil
                            Leaked_CO2(k) = sum(yr_CO2_leak1(Project_size(year, k), :));
                            Produced_CO2(k) = sum(yr_CO2_produced1(Project_size(year, k), :)) ;
                            Injected_CO2(k) = sum(yr_CO2_injected1(Project_size(year, k), :)) ;
                            Stored_CO2(k) = sum(yr_CO2_stored1(Project_size(year, k), :)); % all CO2 that would be stored by this field in its lifetime
                            Stored_CO2_yrl_avg(k) = (Stored_CO2(k))/(n+1); % A verage storage rate per year for this project
                            Produced_Oil(k) = sum(yr_Oil_prod1(Project_size(year, k), :)); % all oil that would be produced by this field in its 30 yr lifetime
                            Produced_Oil_yrly_avg(k) = (Produced_Oil(k))/n+1 ; % Average yearly oil production rate bbl/year
                            OPEX_capture(year) = sum(cap_cost)/(n+1) ; %to get average OPEX of capture over the 30 yr project lifetime
                            Emitted_CO2(k) = (Project_size(year, k)*(n+1)) - Stored_CO2(k) ;
                            
                            %---- Assess next field ----
                            k = k + 1;
                            
                        end
                        
                        %% Sort the NPV of each project at given year
                        % If NPV of k project is found to be positive and within growth rate limitations this project + field will be invested in
                        %------------- Sort NPV values from highest to lowest to get best field to start with -----
                        [values,index] = sort(NPV_sum(year,:), 'descend');
                        
                        test_1 = find(values > 0, 1);

                        
                        %---------Industry Growth limitations Scenario 1------------------
                        %--- If 0 or positive NPV options are available industry
                        %growth is initialised
                        if industry_scenario == 1;
                            %disp('Industry S1');
                            if (isempty(test_1)== 0 ) && year_initial <= 4  % meaning that statement is not true
                                year_initial = 1 + year_initial;
                                max_build = 2^(year_initial-1);
                            elseif ( year_initial < 15 ) && ( year_initial >= 5 )
                                %disp('b')
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.4* sum(build_1(1:(year-1)));
                                max_build = min([num_fields round(build_decimal(year))]) ;
                            elseif ( year_initial < 25 )&& ( year_initial >= 15 )
                                %disp('c')
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.2* sum(build_1(1:(year-1)));
                                max_build = min([num_fields round(build_decimal(year))]) ;
                            elseif year_initial >= 25
                                %disp('d')
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.1* sum(build_1(1:(year-1)));
                                max_build = min([num_fields round(build_decimal(year))]) ;
                            end
                        end
                        
                        %---- Industry growth rate limitations Scenario 2 base case ----
                        %--- If 0 or positive NPV options are available industry
                        %growth is initialised
                        if industry_scenario == 2 ;
                            if (isempty(test_1)== 0 ) && year_initial <= 4  % meaning that statement is not true
                                year_initial = 1 + year_initial;
                                max_build = 1 ; %Limit maximum build in first 5 years to 1 CCS plant per year
                            elseif year_initial >= 5 && sum(build_1(1:year)) < 100
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.26* sum(build_1(1:(year-1))); % conservative estimates - would usually be lower
                                max_build = min([num_fields round(build_decimal(year))]) ;
                            elseif sum(build_1(1:year)) >= 100
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.097 * (sum(build_1(1:(year-1)))) ;
                                max_build = min([num_fields round(build_decimal(year))]);
                            else
                                max_build = num_fields ;
                            end
                        end
                        %---- Industry growth rate limitations Scenario 3 ----
                        %--- If 0 or positive NPV options are available industry
                        %growth is initialised
                        if industry_scenario == 3;
                            %disp('c')
                            if (isempty(test_1)== 0 ) && year_initial <= 4  % meaning that statement is not true
                                year_initial = 1 + year_initial;
                                max_build = 1 ; %Limit maximum build in first 5 years to 1 CCS plant per year
                            elseif year_initial >= 5 && sum(build_1(1:year)) < 100
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.2* sum(build_1(1:(year-1))); % conservative estimates - would usually be lower
                                max_build = min([num_fields round(build_decimal(year))]) ;
                            elseif sum(build_1(1:year)) >= 100
                                year_initial = year_initial + 1 ;
                                build_decimal(year) = 0.03 * (sum(build_1(1:(year-1)))) ;
                                max_build = min([num_fields round(build_decimal(year))]);
                            else
                                max_build = num_fields ;
                            end
                        end
                        
                        %----- Choosing projects with positive NPV that
                        %meet industry growth rate limitations
                        % returns the first k at which NPV is less than or equal to 0
                        test = find(values(1:max_build)<=0,1);
                        
                        if isempty(test)
                            build_new = max_build; % if max_build number of NPVs are > or = to 0 then build the maximum
                        else
                            build_new = test - 1; % the number of projects with NPVs > or = to 0 is less than max_build so only build those
                        end
                        
                        %--- Average NPV each year for successful projects
                        NPV_year (year) = (sum(values(1:build_new)))./build_new ;
                        Oil_rev_avg(year) = sum(Oil_rev_year(year, index(1:build_new)))./build_new ; 
                        CO2_rev_avg(year) = sum(CO2_rev_year(year, index(1:build_new)))./build_new ; 
                        Oil_to_CO2_rev(year) = Oil_rev_avg(year)./CO2_rev_avg(year);
                        
                        %---- Number of plants built in year x
                        build_1(year) = build_new ; % add this to your vector
                        
                        % Eliminate the field the fields that are found economic
                        num_fields = num_fields - build_new;
                        
                        %---- Plot Growth Rate Expansion -----
                        cumulative_build (year) = sum(build_1(1:year)); % cumulative number of plants built
                        
                        %plot(1:year, cumulative_build(1:year));
                        %semilogy(1:year, cumulative_build(1:year));
                        if build_new > 0
                            Poro_avg (year) = sum(poro(index(1:build_new)))/build_new; % average porosity for successful projects
                            Soil_avg (year) = 1 - sum(Swi(index(1:build_new)))/build_new ; % average initial oil saturation for successful projects
                            h_avg (year) = sum(h (index(1:build_new)))/build_new;
                            depth_avg (year) = sum(depth (index(1:build_new)))/build_new;
                            perm_avg (year) = sum(perm (index(1:build_new)))/build_new ;
                            Area_avg (year) = sum(A(index (1:build_new)))/build_new ;
                        end
                        
                        %-Concatenating vectors for reduced number of fields to
                        %evaluate the next year
                        HCPV_pp_x(index(1:build_new)) = [];
                        HCPV_x(index(1:build_new)) = [];
                        p(index(1:build_new)) = [];
                        pp(index(1:build_new)) = [];
                        poro(index(1:build_new)) = [];
                        Swi(index(1:build_new)) = [];
                        h (index(1:build_new)) = [];
                        depth (index(1:build_new)) = [];
                        perm (index(1:build_new)) = [];
                        A (index (1:build_new)) = [];
                        p_x(index(1:build_new)) = [];
                        
                        %----Reporting results-----
                        Capture_capex(year) = CAPEX_cap ;
                        EOR_capex(year) = CAPEX_EOR;
                        %Transport_capex(year) = CAPEX_trans;
                        
                        Capacity_build(year) = sum(Project_size(year, index(1:build_new))); %Total capacity installed per year
                        Cumulative_capacity_build(year) = sum(Capacity_build(1:year)); %Total cumulative capacity installed per year
                        
                        %%--- CO2 fate---------
                        %---- CO2 injected, emitted and leaked from field ---
                        Injected_CO2_year(year) = sum(Injected_CO2(index(1:build_new)));
                        
                        Produced_CO2_year(year) = sum(Produced_CO2(index(1:build_new)));
                        Cumulative_produced(year) = sum(Produced_CO2_year(1:year)) ;
                        
                        Emitted_CO2_year (year) = sum(Emitted_CO2(index(1:build_new)));
                        Cumulative_emitted (year) = sum(Emitted_CO2_year(1:year));
                        
                        Leaked_CO2_year(year) = sum(Leaked_CO2(index(1:build_new)));
                        Cumulative_leaked(year) = sum(Leaked_CO2_year(1:year));
                        
                        %-- CO2 not captured from power plant
                        Cumulative_not_captured = 0.1.*Cumulative_capacity_build*30; %cumulative not captured
                        
                        %----Stored CO2 --------
                        Stored_CO2_year(year) = sum(Stored_CO2(index(1:build_new))); % CO2 storage deployment on that year (total amount of CO2 that would be stored considering each 30 yearlong project)
                        Cumulative_stored(year) = sum(Stored_CO2_year(1:year)); % Cumulative amount of CO2 stored over all 30 year projects
                        Stored_CO2_yrl_avg_year(year) = sum(Stored_CO2_yrl_avg(index(1:build_new))); % average yearly CO2 storage of industry (for all projects built that year)
                        
                        % Gives CO2 Storage industry growth
                        Cumulative_stored_yrly (year) = sum(Stored_CO2_yrl_avg_year(1:year)); %Cumulative average yearly CO2 storage of industry
                        
                        %%---- Oil fate ------
                        Produced_Oil_year(year) = sum(Produced_Oil(index(1:build_new))); %Produced by all projects with go ahead in their 30 year lifetime
                        Produced_Oil_yrly_avg_year(year) = sum(Produced_Oil_yrly_avg(index(1:build_new))); % average yearly oil production of industry (for all projects built that year)
                        Cumulative_oil (year) = sum(Produced_Oil_year(1:year)); % Cumulative amount of oil produced for 30-year long projects deployed
                        %Gives Oil industry growth
                        Cumulative_oil_yrly (year) = sum (Produced_Oil_yrly_avg_year(1:year)); %Cumulative average yearly oil production of industry
                        
                        %---- Cost of CO$_2$ captured
                        CRF(year) = (RR*(1+RR)^(n))/(((1+RR)^(n))-1); % Capital recovery factor to annualize capital cost
                        
                        %re-evaluate CAPEX_cap
                        Cost_of_CO2(year) = (OPEX_capture(year)/10^6).*(1/((1+inf).^(year-1))) + (CAPEX_cap*CRF(year))/(10^6); %$/tCO2
                        Cost_of_CO2_adjusted(year) = Cost_of_CO2(year).*(1/((1+inf).^(year-1)));
                        %year;
                        result = Cost_of_CO2;
                    end
                    %% Uncomment to Plot Project Based Industry Growth Rate Figure
                    %                                         x = (1 : year);
                    %                                         y = (100.^(ones(year,1)))';
                    %                                         %% Plot industry growth rate figure
                    %                                         figure
                    %                                         plot(1:year, cumulative_build(1:year), x, y, 'Linewidth', 2);
                    %                                         %semilogy(1:year, cumulative_build(1:year), x, y, 'Linewidth', 2);
                    %                                         ylabel('Number of plants built','FontSize', 16);
                    %                                         xlabel('Year', 'FontSize', 16);
                    %                                         %title ('CCS Industry growth rate');
                    %                                         set(gca, 'FontSize', 16);
                    
                    %% Result display
                    %--Average field properties
                    Poro_YR = sum(Poro_avg (1:length(Poro_avg)))/length(Poro_avg); % average porosity for successful projects
                    Soil_YR = sum(Soil_avg (1:length(Soil_avg)))/length(Soil_avg);   % average initial oil saturation for successful projects
                    h_YR  = sum(h_avg (1:length(h_avg)))/length(h_avg);
                    depth_YR  = sum(depth_avg (1:length(depth_avg)))/length(depth_avg);
                    perm_YR = sum(perm_avg (1:length(perm_avg)))/length(perm_avg);
                    Area_YR  = sum(Area_avg (1:length(Area_avg)))/length(Area_avg);
%                     
                    %--Cost of CO2/tCO2 captured
                    Cost_of_CO2_2050 = Cost_of_CO2(d);
                    Cost_of_CO2_real = min(Cost_of_CO2);
                    
                    %--- CCS plants & capacity deployed
                    CCS_2050_capacity = sum(Capacity_build(1:d));
                    
                    %---- Cost reduction calculations from technological learning
                    Capture_cost_reduction = -((Capture_capex(35) - Capture_capex(1))/Capture_capex(1))*100 ; % percentage reduction in capture cost per MtCO2
                    %EOR_cost_reduction = -((EOR_capex(35) - EOR_capex(1))/EOR_capex(1))*100; % percentage reduction in capital cost per EOR pattern
                    
                    %---- Result outputs
                    storage = sum(Stored_CO2_year);
                    CO2_emitted = sum(Produced_CO2_year);
                    CO2_emitted_real = sum(Emitted_CO2_year); % actual CO2 emitted
                    CO2_not_captured = sum(Not_captured);
                    CO2_leaked_total = sum(Leaked_CO2_year);
                    ratio1 = storage/CO2_emitted_real;
                    oil_tosell = sum(Produced_Oil_year);
                    ratio2 = storage/CCS_2050_capacity*30 ; 
                    
                    %---- Average yearly production rates for industry
                    Oil_industry = (Produced_Oil_yrly_avg_year*10^(-6))./build_1; %MMbbl/year oil produced
                    %--- Oil industry growth rate compared to US CO2-EOR
                    %industry in 2015
                    US_CO2EOR = 156.95; %MMbbl/year of oil produced in US
                    CCS_today = 27; % 2016 CO_2 capture rate globally IEA
                    Oil_growth = (((Cumulative_oil_yrly(d)*(10^-6))/US_CO2EOR)^(1/d) - 1)*100 ;
                    CCS_growth = (((CCS_2050_capacity/CCS_today)^(1/d))-1)*100;
                    %CCS_growth = (((CCS_2050_capacity/Q_i)^(1/d))-1)*100;
                    Oilprod_to_CO2store = oil_tosell/(storage*10^6) ;
                    utilisation_factor = sum(Injected_CO2_year)*10^6/oil_tosell;
                    
                    %% Results ouput
                    % Table of inputs and static ouputs
                    %Inputs
                    Variables = {'Price of Oil 2016 $/bbl'; 'Oil price growth rate'; 'CO2 tax 2016 $/t'; 'CO2 tax by 2050 $/t'; ...
                        'Learning Rate'; 'Initial Capital Cost of Capture M$'; 'Industry Scenario'; 'Oil Factor'; 'Nominal Discount Rate'; 'Cost of Electricity $/MWh'; 'Inflation rate'};
                    Inputs = [pOil_2016; g; pCO2_initial; pCO2; LR; capex_cap_ini*10^-6; industry_scenario; oil_factor; NR; COE; inf];
                    T_1 = table(Inputs, 'RowNames', Variables);
                    disp(T_1)
                    writetable(T_1, 'Inputs.txt','WriteRowNames', true);
                    
                    %Project outputs
                    Results = {'Capacity installed by 2050 MtCO_2/year'; 'Cost of Capturing CO_2 by 2050 $/tCO_2';...
                        'Minimum Cost of Capturing CO_2 $/tCO2'; ....
                        'Total CO_2 stored by 2050 for successful projects Mt'; ...
                        'Total Oil produced by 2050 for successful projects Bbbl';
                        'EOR CAGR from 2015 US CO_2-EOR Industry (%)';...
                        'CCS CAGR from 2016 Industry (%)';...
                        'Ratio of CO_2 stored to CO2 emitted'; ...
                        'Oil produced bbl per tCO_2 stored'; ...
                        'Utilisation factor tCO2 injected/bbl prod.'};
                    Outputs = [CCS_2050_capacity; Cost_of_CO2_2050; Cost_of_CO2_real; storage; oil_tosell*10^-9; Oil_growth; CCS_growth; ratio1; Oilprod_to_CO2store; utilisation_factor];
                    T_2 = table(Outputs, 'RowNames', Results);
                    disp(T_2)
                    writetable(T_2, 'Outputs.txt', 'WriteRowNames', true);
                    
                    %Average field characteristics for successful projects
                    Field_charac = {'Average Porosity'; 'Average Permeability (mD)'; ...
                        'Average Initial Oil Saturation'; 'Average Net Pay Thickness (m)';...
                        'Average field depth (m)'; 'Average field Area(km2)'};
                    Characteristics = [Poro_YR; perm_YR*10^15;...
                        Soil_YR; h_YR; depth_YR;  Area_YR*10^-6];
                    T_3 = table(Characteristics, 'RowNames', Field_charac);
                    disp(T_3)
                    writetable(T_3, 'Field_characteristics.txt','WriteRowNames', true)


%end of main MIICE code
